sphinx-icon
===========

.. image:: https://img.shields.io/badge/License-BSD_2--Clause-yellow.svg
    :target: https://github.com/sphinx-contrib/icon/blob/main/LICENSE
    :alt: License: BSD 2-Clause

.. image:: https://img.shields.io/pypi/v/sphinx-icon?logo=python&logoColor=white&color=blue
    :target: https://pypi.org/project/sphinx-icon/
    :alt: PyPI

.. image:: https://img.shields.io/pypi/pyversions/sphinx-icon?logo=python&logoColor=white&color=blue
    :target: https://pypi.org/project/sphinx-icon/
    :alt: supported Python version

.. image:: https://img.shields.io/github/actions/workflow/status/sphinx-contrib/icon/unit.yaml?logo=github&logoColor=white
    :target: https://github.com/sphinx-contrib/icon/actions/workflows/unit.yaml
    :alt: GitHub Workflow Status

.. image:: https://img.shields.io/codecov/c/github/sphinx-contrib/icon?logo=codecov&logoColor=white
    :target: https://codecov.io/gh/sphinx-contrib/icon
    :alt: Codecov

.. image:: https://img.shields.io/readthedocs/sphinx-icon?logo=readthedocs&logoColor=white
    :target: https://sphinx-icon.readthedocs.io/en/latest/?badge=latest
    :alt: Read the Docs

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Black badge

.. image:: https://img.shields.io/badge/Conventional%20Commits-1.0.0-yellow.svg
   :target: https://conventionalcommits.org
   :alt: conventional commit

Overview
--------

:code:`sphinx-icon` is a Sphinx extention to allow developers to use the :code:`icon` role to display inlined icons.
The extention currently supports only Fontawsome 6.3.0 icons.

.. code-block:: rst

    I'm an :icon:`fa-solid fa-folder` icon.
    I'm an :icon:`fa-regular fa-user` icon.
    I'm an :icon:`fa-brands fa-500px` icon.

.. image:: https://raw.githubusercontent.com/sphinx-contrib/icon/main/docs/_static/demo.png
    :alt: demo result

Please go to our `doc <https://sphinx-icon.readthedocs.io/en/latest/>`__ if you want to know more.



Contribute
----------

If you want to contribute you can fork the project in you own repository and then use it.
If you consider working with us, please follow the `contributing guidelines <https://github.com/sphinx-contrib/icon/blob/main/CONTRIBUTING.rst>`__.
Meet our `contributor <https://github.com/sphinx-contrib/icon/blob/main/AUTHORS.rst>`__.
